@@ -1,6 +1,7 @@
-from typing import Any, Tuple, Dict
+from typing import Any, Tuple, Dict, Type
 
 from datacode.logger import logger
+from datacode.models.dethash import HashDictOptions, DeterministicHashDictMixin
 
 
 class PreservedAttribute:
@@ -35,23 +36,21 @@ class DatacodeOptions:
     >>> dc.options.reset()
     """
 
-    _orig_class_attrs: Dict[Tuple[str, str], PreservedAttribute] = {}
+    _orig_class_attrs: Dict[Tuple[Type, str], PreservedAttribute] = {}
 
     def reset(self):
         """
         Undo any changes made through the options interface
         :return:
         """
-        logger.debug(f'Resetting datacode options')
-        for (class_name, attr), orig_value in self._orig_class_attrs.items():
+        logger.debug(f"Resetting datacode options")
+        for (klass, attr), orig_value in self._orig_class_attrs.items():
             if orig_value.attr_existed:
-                self._set_class_attr(
-                    class_name,
-                    attr,
-                    orig_value.value,
+                setattr(
+                    klass, attr, orig_value.value,
                 )
             else:
-                self._delete_class_attr(class_name, attr)
+                delattr(klass, attr)
         self._orig_class_attrs = {}
 
     def set_class_attr(
@@ -65,33 +64,38 @@ class DatacodeOptions:
         :param value: Value to set the attribute to
         :return: same options instance
         """
-        logger.debug(f'Setting datacode options for class attr {class_name}.{attr} to {value}')
-        orig_value = self._set_class_attr(class_name, attr, value)
-        self._orig_class_attrs[(class_name, attr)] = orig_value
+        import datacode as dc
+
+        logger.debug(
+            f"Setting datacode options for class attr {class_name}.{attr} to {value}"
+        )
+
+        klass = getattr(dc, class_name)
+        self._set_class_attr(klass, attr, value)
+        return self
+
+    def set_hash_options(self, options: HashDictOptions) -> 'DatacodeOptions':
+        """
+        Control how pipelines determine whether the result is cached. Each time
+        a pipeline is run it calculates a hash it calculates a hash of its options
+        and its data sources to determine whether it has already run with the
+        same settings.
+
+        ``deepdiff.DeepHash` is used to determine the hash. DeepHash options
+        can be passed to control the hashing behavior. The :py:class:`HashDictOptions`
+        typed dictionary is provided for convenience and matches those options
+
+        :param options: dict of kwargs that would be passed to ``deepdiff.DeepHash``
+        :return: same options instance
+        """
+        self._set_class_attr(DeterministicHashDictMixin, 'hash_dict_options', options)
         return self
 
     def _set_class_attr(
-        self, class_name: str, attr: str, value: Any,
-    ) -> PreservedAttribute:
-        import datacode as dc
-
-        klass = getattr(dc, class_name)
-
-        try:
-            orig_value = getattr(klass, attr)
-            has_attr = True
-        except AttributeError:
-            orig_value = None
-            has_attr = False
-
-        setattr(klass, attr, value)
-        return PreservedAttribute(attr, orig_value, attr_existed=has_attr)
-
-    def _delete_class_attr(self, class_name: str, attr: str):
-        import datacode as dc
-
-        klass = getattr(dc, class_name)
-        delattr(klass, attr)
+        self, klass: Type, attr: str, value: Any,
+    ):
+        orig_value = _set_class_attr(klass, attr, value)
+        self._orig_class_attrs[(klass, attr)] = orig_value
 
     def __enter__(self):
         return self
@@ -100,4 +104,16 @@ class DatacodeOptions:
         self.reset()
 
 
+def _set_class_attr(klass: Type, attr: str, value: Any):
+    try:
+        orig_value = getattr(klass, attr)
+        has_attr = True
+    except AttributeError:
+        orig_value = None
+        has_attr = False
+
+    setattr(klass, attr, value)
+    return PreservedAttribute(attr, orig_value, attr_existed=has_attr)
+
+
 options = DatacodeOptions()
